@@ -1,9 +1,6 @@
 package Dancer::Logger::LogAny;
-{
-  $Dancer::Logger::LogAny::VERSION = '0.002';
-}
 # ABSTRACT: Use Log::Any to control logging from your Dancer app
-
+$Dancer::Logger::LogAny::VERSION = '0.003';
 use strict;
 use warnings;
 use Dancer::Config 'setting';
@@ -20,8 +17,10 @@ sub init {
         require Log::Any::Adapter;
         Log::Any::Adapter->set (@{$settings->{logger}});
     }
-    my $category = $settings->{category} || '';
-    $_logger = Log::Any->get_logger (category => $category);
+    my %param = exists $settings->{category}
+        ? (category => $settings->{category})
+        : ();
+    $_logger = Log::Any->get_logger (%param);
 }
 
 sub _log {
@@ -33,15 +32,18 @@ sub _log {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dancer::Logger::LogAny - Use Log::Any to control logging from your Dancer app
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -97,10 +99,9 @@ Michael Alan Dorman <mdorman@ironicdesign.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Michael Alan Dorman.
+This software is copyright (c) 2015 by Michael Alan Dorman.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
